@@ -2083,12 +2083,12 @@ class ReadOnlyDirectory(Mapping):
                             last = step
                             step = step[head]
                             if isinstance(step, uproot.behaviors.TBranch.HasBranches):
-                                return step["/".join([tail] + items[i + 1 :])]
+                                return step["/".join([tail, *items[i + 1 :]])]
                             else:
                                 raise uproot.KeyInFileError(
                                     where,
                                     because=repr(head)
-                                    + " is not a TDirectory, TTree, or TBranch",
+                                    + " is not a TDirectory, TTree, TBranch, RNTuple, or RField",
                                     keys=[key.fName for key in last._keys],
                                     file_path=self._file.file_path,
                                 )
@@ -2098,14 +2098,20 @@ class ReadOnlyDirectory(Mapping):
                             last = step
                             step = step[item]
 
-                    elif isinstance(step, uproot.behaviors.TBranch.HasBranches):
+                    elif isinstance(
+                        step,
+                        (
+                            uproot.behaviors.TBranch.HasBranches,
+                            uproot.behaviors.RNTuple.HasFields,
+                        ),
+                    ):
                         return step["/".join(items[i:])]
 
                     else:
                         raise uproot.KeyInFileError(
                             where,
                             because="/".join(items[:i])
-                            + " is not a TDirectory, TTree, or TBranch",
+                            + " is not a TDirectory, TTree, TBranch, RNTuple, or RField",
                             keys=[key.fName for key in last._keys],
                             file_path=self._file.file_path,
                         )
