@@ -269,17 +269,31 @@ def to_writable(obj):
         if len(axes) == 1:
             if obj.kind == "MEAN":
                 if hasattr(obj, "storage_type"):
-                    if "fSumw2" in obj.metadata.keys():
+                    obj_sum = obj.sum()
+                    # Use __dir__ instead of hasattr to avoid a warning
+                    if (
+                        "metadata" in obj.__dir__()
+                        and obj.metadata is not None
+                        and "fSumw2" in obj.metadata.keys()
+                    ):
                         fSumw2 = obj.metadata["fSumw2"]
+                        fTsumw = obj_sum["sum_of_weights"]
+                        fTsumw2 = obj_sum["sum_of_weights_squared"]
+                    elif obj.storage_type is boost_histogram.storage.WeightedMean:
+                        fSumw2 = obj.view()["sum_of_weights_squared"]
+                        fTsumw = obj_sum["sum_of_weights"]
+                        fTsumw2 = obj_sum["sum_of_weights_squared"]
                     else:
-                        raise ValueError(f"fSumw2 has not been set for {obj}")
+                        fSumw2 = obj.view()["count"]
+                        fTsumw = obj_sum["count"]
+                        fTsumw2 = obj_sum["count"]
                     return to_TProfile(
                         fName=None,
                         fTitle=title,
                         data=obj.values(flow=True),
                         fEntries=obj.size + 1,
-                        fTsumw=obj.sum()["sum_of_weights"],
-                        fTsumw2=obj.sum()["sum_of_weights_squared"],
+                        fTsumw=fTsumw,
+                        fTsumw2=fTsumw2,
                         fTsumwx=0,
                         fTsumwx2=0,
                         fTsumwy=0,
